"""
    Patches OFS.Image.File, OFS.DTMLDocument.DTMLDocument
    and OFS.DTMLMethod.DTMLMethod, so that a "Text Convert"
    tab is available for all objects based on them.
"""
# $Id: TextConvertPatch.py,v 1.3 2001/10/21 10:17:19 adrian Exp $
#
# $Log: TextConvertPatch.py,v $
# Revision 1.3  2001/10/21 10:17:19  adrian
# Remove unneeded import
#
# Revision 1.2  2001/10/21 00:11:07  adrian
# Fixed bug where "content_type" was inherited if it was not found.
#
#
__version__ = '$Revision: 1.3 $'[11:-2]

import OFS.Image
import OFS.DTMLDocument
import OFS.DTMLMethod
import Globals
import whrandom
import Acquisition
try:
    import Products.ZStyleSheet.ZStyleSheet
    useZSS = 1
except:
    useZSS = 0

def filterTextConvertTab(obj):
    if hasattr(Acquisition.aq_base(obj), 'content_type'):
        if (obj.content_type[:5]!='text/'):
            return 0
    return 1

convertOptions = ['DTML Document', 'DTML Method']
if useZSS:
    convertOptions.append('ZStyleSheet')

def manage_performTextConvert(self, data, convert, inplace='0', keepold='0', REQUEST=None):
    """ Attempts to perform a TextConvert operation. """
    parent = self.aq_parent
    oldName = "%s" % self.id()
    destName = "%s" % self.id()
    while hasattr(parent, destName):
        destName = "%s_%d" % (self.id(), whrandom.uniform(1000, 10000))
    if inplace!='0':
        tmpName = oldName
        oldName = destName
        destName = tmpName
        parent.manage_renameObject(destName, oldName)
    if convert == 'DTML Method':
        if (hasattr(self, 'content_type')):
            data = """<dtml-call "RESPONSE.setHeader('content-type', '%s')">\n\n%s""" % (self.content_type, self.data)
        OFS.DTMLMethod.addDTMLMethod(parent, id=destName, title=self.title, file=data)
    elif convert == 'DTML Document':
        if (hasattr(self, 'content_type')):
            data = """<dtml-call "RESPONSE.setHeader('content-type', '%s')">\n\n%s""" % (self.content_type, self.data)
        OFS.DTMLDocument.addDTMLDocument(parent, id=destName, title=self.title, file=data)
    elif useZSS and convert == 'ZStyleSheet':
        Products.ZStyleSheet.ZStyleSheet.manage_addZStyleSheet(parent, id=destName, title=self.title, file=self.data)
    else:
        raise "Conversion Error", "What did you want to convert TO?"
    if keepold=='0':
        parent.manage_delObjects([oldName])
    if REQUEST:
        if inplace=='1':
            if keepold=='0':
                message="Converted to %s called '%s' (Original deleted)" % (convert, destName)
                item=getattr(parent, destName)
            else:
                message="Converted to %s called '%s' (Original renamed to %s)" % (convert, destName, oldName)
                item=getattr(parent, oldName)
        else:
            message="Converted to %s called '%s' (Original unchanged)" % (convert, destName)
            item=getattr(parent, oldName)
        return item.manage_main(item, REQUEST, manage_tabs_message=message)
    return None

targets = (
    OFS.Image.File,
    OFS.DTMLDocument.DTMLDocument,
    OFS.DTMLMethod.DTMLMethod
)
manage_options = (
    {'label':'Text Convert', 'action':'manage_performTextConvertForm',
     'filter':filterTextConvertTab, 'help':('PatchKit', 'TextConvert.stx'),
    },
)
methods = {
    'manage_performTextConvertForm':
        Globals.DTMLFile('www/textConvert', globals()),
    'manage_performTextConvert': manage_performTextConvert,
    'textConvertOptions': convertOptions
}
